==> aptechka-0.42.1.tgz: package/lib/element-resizer/index.js <==
var h = (n) => {
  throw TypeError(n);
};
var y = (n, t, s) => t.has(n) || h("Cannot " + s);
var r = (n, t, s) => (y(n, t, "read from private field"), s ? s.call(n) : t.get(n)), b = (n, t, s) => t.has(n) ? h("Cannot add the same private member more than once") : t instanceof WeakSet ? t.add(n) : t.set(n, s), u = (n, t, s, e) => (y(n, t, "write to private field"), e ? e.call(n, s) : t.set(n, s), s);
import { i as p } from "../browser-0zX67oeU.js";
import { g as w } from "../dom-CVWzyXPH.js";
var i, o, f;
class z {
  constructor() {
    b(this, i, []);
    b(this, o, null);
    b(this, f, (t) => {
      r(this, i).map((e) => ({
        subscriber: e,
        entry: t.find((l) => l.target === e.element)
      })).forEach((e) => {
        e.entry && (e.subscriber.entry = e.entry, e.subscriber.callback(e.entry));
      });
    });
    p && window.ResizeObserver && u(this, o, new ResizeObserver(r(this, f)));
  }
  subscribe(t, s) {
    const e = w(t);
    if (!e)
      return () => {
      };
    const l = r(this, i).find(
      (c) => c.element === e
    );
    if (!l)
      r(this, o).observe(e);
    else {
      const c = r(this, i).find(
        (m) => m.element === e && m.entry
      );
      c != null && c.element.isConnected && s(c.entry);
    }
    return r(this, i).push({
      element: e,
      callback: s,
      entry: (l == null ? void 0 : l.entry) || null
    }), () => {
      this.unsubscribe(s);
    };
  }
  unsubscribe(t) {
    const s = r(this, i).find(
      (e) => e.callback === t
    );
    s && (u(this, i, r(this, i).filter(
      (e) => e.callback !== s.callback
    )), r(this, i).find((e) => e.element === s.element) || r(this, o).unobserve(s.element));
  }
}
i = new WeakMap(), o = new WeakMap(), f = new WeakMap();
const g = new z();
export {
  z as ElementResizer,
  g as elementResizer
};

==> aptechka-0.44.1.tgz: package/lib/element-resizer/index.js <==
var h = (n) => {
  throw TypeError(n);
};
var y = (n, t, s) => t.has(n) || h("Cannot " + s);
var r = (n, t, s) => (y(n, t, "read from private field"), s ? s.call(n) : t.get(n)), b = (n, t, s) => t.has(n) ? h("Cannot add the same private member more than once") : t instanceof WeakSet ? t.add(n) : t.set(n, s), u = (n, t, s, e) => (y(n, t, "write to private field"), e ? e.call(n, s) : t.set(n, s), s);
import { i as p } from "../index-euf5anj6.js";
import { g as w } from "../dom-CVWzyXPH.js";
var i, o, f;
class z {
  constructor() {
    b(this, i, []);
    b(this, o, null);
    b(this, f, (t) => {
      r(this, i).map((e) => ({
        subscriber: e,
        entry: t.find((l) => l.target === e.element)
      })).forEach((e) => {
        e.entry && (e.subscriber.entry = e.entry, e.subscriber.callback(e.entry));
      });
    });
    p && window.ResizeObserver && u(this, o, new ResizeObserver(r(this, f)));
  }
  subscribe(t, s) {
    const e = w(t);
    if (!e)
      return () => {
      };
    const l = r(this, i).find(
      (c) => c.element === e
    );
    if (!l)
      r(this, o).observe(e);
    else {
      const c = r(this, i).find(
        (m) => m.element === e && m.entry
      );
      c != null && c.element.isConnected && s(c.entry);
    }
    return r(this, i).push({
      element: e,
      callback: s,
      entry: (l == null ? void 0 : l.entry) || null
    }), () => {
      this.unsubscribe(s);
    };
  }
  unsubscribe(t) {
    const s = r(this, i).find(
      (e) => e.callback === t
    );
    s && (u(this, i, r(this, i).filter(
      (e) => e.callback !== s.callback
    )), r(this, i).find((e) => e.element === s.element) || r(this, o).unobserve(s.element));
  }
}
i = new WeakMap(), o = new WeakMap(), f = new WeakMap();
const g = new z();
export {
  z as ElementResizer,
  g as elementResizer
};
